key = {
  "saxs_1d": "/exchange/partition-mean-total",
  "Iqp": "/exchange/partition-mean-partial",
  "ql_sta": "/xpcs/sqlist",
  "ql_dyn": "/xpcs/dqlist",
  "dqmap": "/xpcs/dqmap",
  "sqmap": "/xpcs/sqmap",
  "type": "/xpcs/analysis_type",
  "t0": "/measurement/instrument/detector/exposure_period",
  "t1": "/measurement/instrument/detector/exposure_time",
  "tau": "/exchange/tau",
  "g2": "/exchange/norm-0-g2",
  "g2_err": "/exchange/norm-0-stderr",
  "saxs_2d": "/exchange/pixelSum",
  "Int_t": "/exchange/frameSum",
  "ccd_x0": "/measurement/instrument/acquisition/beam_center_x",
  "ccd_y0": "/measurement/instrument/acquisition/beam_center_y",
  "det_dist": "/measurement/instrument/detector/distance",
  "pix_dim": "/measurement/instrument/detector/x_pixel_size",
  "X_energy": "/measurement/instrument/source_begin/energy",
  "xdim": "/measurement/instrument/detector/x_dimension",
  "ydim": "/measurement/instrument/detector/y_dimension",
  "c2_half": "/exchange/C2T_all",
  "g2_full": "/exchange/g2full",
  "g2_partials": "/exchange/g2partials",
  "G2": "/exchange/G2",
  "IP": "/exchange/IF",
  "IF": "/exchange/IP"
}
