# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xpcs_viewer/ui/xpcs.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_mainWindow(object):
    def setupUi(self, mainWindow):
        mainWindow.setObjectName("mainWindow")
        mainWindow.resize(1875, 1035)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(mainWindow.sizePolicy().hasHeightForWidth())
        mainWindow.setSizePolicy(sizePolicy)
        mainWindow.setMinimumSize(QtCore.QSize(1024, 0))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/newPrefix/icons8-giraffe-full-body-100.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/icons/icons8-giraffe-full-body-100.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        mainWindow.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(mainWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        self.file_panel = QtWidgets.QFrame(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.file_panel.sizePolicy().hasHeightForWidth())
        self.file_panel.setSizePolicy(sizePolicy)
        self.file_panel.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.file_panel.setFrameShadow(QtWidgets.QFrame.Raised)
        self.file_panel.setObjectName("file_panel")
        self.gridLayout_32 = QtWidgets.QGridLayout(self.file_panel)
        self.gridLayout_32.setObjectName("gridLayout_32")
        self.splitter_4 = QtWidgets.QSplitter(self.file_panel)
        self.splitter_4.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_4.setObjectName("splitter_4")
        self.splitter = QtWidgets.QSplitter(self.splitter_4)
        self.splitter.setOrientation(QtCore.Qt.Vertical)
        self.splitter.setObjectName("splitter")
        self.layoutWidget = QtWidgets.QWidget(self.splitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_2 = QtWidgets.QLabel(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_6.addWidget(self.label_2)
        self.work_dir = QtWidgets.QLineEdit(self.layoutWidget)
        self.work_dir.setMinimumSize(QtCore.QSize(200, 0))
        self.work_dir.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.work_dir.setClearButtonEnabled(True)
        self.work_dir.setObjectName("work_dir")
        self.horizontalLayout_6.addWidget(self.work_dir)
        self.verticalLayout.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.pushButton = QtWidgets.QPushButton(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton.sizePolicy().hasHeightForWidth())
        self.pushButton.setSizePolicy(sizePolicy)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout_2.addWidget(self.pushButton)
        self.pushButton_11 = QtWidgets.QPushButton(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_11.sizePolicy().hasHeightForWidth())
        self.pushButton_11.setSizePolicy(sizePolicy)
        self.pushButton_11.setObjectName("pushButton_11")
        self.horizontalLayout_2.addWidget(self.pushButton_11)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.box_source = QtWidgets.QGroupBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(20)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.box_source.sizePolicy().hasHeightForWidth())
        self.box_source.setSizePolicy(sizePolicy)
        self.box_source.setMinimumSize(QtCore.QSize(0, 80))
        self.box_source.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.box_source.setObjectName("box_source")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.box_source)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.list_view_source = QtWidgets.QListView(self.box_source)
        self.list_view_source.setDragEnabled(True)
        self.list_view_source.setAlternatingRowColors(True)
        self.list_view_source.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.list_view_source.setObjectName("list_view_source")
        self.gridLayout_5.addWidget(self.list_view_source, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.box_source)
        self.layoutWidget1 = QtWidgets.QWidget(self.splitter)
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.layoutWidget1)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.gridLayout_18 = QtWidgets.QGridLayout()
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.filter_type = QtWidgets.QComboBox(self.layoutWidget1)
        self.filter_type.setObjectName("filter_type")
        self.filter_type.addItem("")
        self.filter_type.addItem("")
        self.gridLayout_18.addWidget(self.filter_type, 0, 0, 1, 1)
        self.filter_str = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.filter_str.sizePolicy().hasHeightForWidth())
        self.filter_str.setSizePolicy(sizePolicy)
        self.filter_str.setMaximumSize(QtCore.QSize(16777215, 100))
        self.filter_str.setClearButtonEnabled(True)
        self.filter_str.setObjectName("filter_str")
        self.gridLayout_18.addWidget(self.filter_str, 0, 1, 1, 2)
        self.pushButton_2 = QtWidgets.QPushButton(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_2.sizePolicy().hasHeightForWidth())
        self.pushButton_2.setSizePolicy(sizePolicy)
        self.pushButton_2.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButton_2.setObjectName("pushButton_2")
        self.gridLayout_18.addWidget(self.pushButton_2, 1, 0, 1, 2)
        self.pushButton_3 = QtWidgets.QPushButton(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_3.sizePolicy().hasHeightForWidth())
        self.pushButton_3.setSizePolicy(sizePolicy)
        self.pushButton_3.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButton_3.setObjectName("pushButton_3")
        self.gridLayout_18.addWidget(self.pushButton_3, 1, 2, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout_18)
        self.box_target = QtWidgets.QGroupBox(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.box_target.sizePolicy().hasHeightForWidth())
        self.box_target.setSizePolicy(sizePolicy)
        self.box_target.setMinimumSize(QtCore.QSize(0, 120))
        self.box_target.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.box_target.setObjectName("box_target")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.box_target)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_30 = QtWidgets.QLabel(self.box_target)
        self.label_30.setObjectName("label_30")
        self.horizontalLayout_9.addWidget(self.label_30)
        self.progress_bar = QtWidgets.QProgressBar(self.box_target)
        self.progress_bar.setMaximumSize(QtCore.QSize(16777215, 20))
        self.progress_bar.setProperty("value", 0)
        self.progress_bar.setObjectName("progress_bar")
        self.horizontalLayout_9.addWidget(self.progress_bar)
        self.gridLayout_4.addLayout(self.horizontalLayout_9, 2, 0, 1, 1)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.box_auto_update = QtWidgets.QCheckBox(self.box_target)
        self.box_auto_update.setChecked(True)
        self.box_auto_update.setObjectName("box_auto_update")
        self.horizontalLayout_7.addWidget(self.box_auto_update)
        self.btn_load_data = QtWidgets.QPushButton(self.box_target)
        self.btn_load_data.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btn_load_data.sizePolicy().hasHeightForWidth())
        self.btn_load_data.setSizePolicy(sizePolicy)
        self.btn_load_data.setObjectName("btn_load_data")
        self.horizontalLayout_7.addWidget(self.btn_load_data)
        self.pushButton_13 = QtWidgets.QPushButton(self.box_target)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_13.sizePolicy().hasHeightForWidth())
        self.pushButton_13.setSizePolicy(sizePolicy)
        self.pushButton_13.setObjectName("pushButton_13")
        self.horizontalLayout_7.addWidget(self.pushButton_13)
        self.gridLayout_4.addLayout(self.horizontalLayout_7, 1, 0, 1, 1)
        self.list_view_target = QtWidgets.QListView(self.box_target)
        self.list_view_target.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.list_view_target.setObjectName("list_view_target")
        self.gridLayout_4.addWidget(self.list_view_target, 0, 0, 1, 1)
        self.verticalLayout_2.addWidget(self.box_target)
        self.tabWidget = QtWidgets.QTabWidget(self.splitter_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setMinimumSize(QtCore.QSize(600, 0))
        self.tabWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.tabWidget.setObjectName("tabWidget")
        self.tab1_1 = QtWidgets.QWidget()
        self.tab1_1.setObjectName("tab1_1")
        self.gridLayout_26 = QtWidgets.QGridLayout(self.tab1_1)
        self.gridLayout_26.setObjectName("gridLayout_26")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_38 = QtWidgets.QLabel(self.tab1_1)
        self.label_38.setObjectName("label_38")
        self.horizontalLayout_4.addWidget(self.label_38)
        self.saxs2d_display = QtWidgets.QLineEdit(self.tab1_1)
        self.saxs2d_display.setMinimumSize(QtCore.QSize(500, 0))
        self.saxs2d_display.setAcceptDrops(False)
        self.saxs2d_display.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.saxs2d_display.setReadOnly(True)
        self.saxs2d_display.setObjectName("saxs2d_display")
        self.horizontalLayout_4.addWidget(self.saxs2d_display)
        self.gridLayout_26.addLayout(self.horizontalLayout_4, 0, 0, 1, 1)
        self.pg_saxs = ImageViewDev(self.tab1_1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pg_saxs.sizePolicy().hasHeightForWidth())
        self.pg_saxs.setSizePolicy(sizePolicy)
        self.pg_saxs.setObjectName("pg_saxs")
        self.gridLayout_26.addWidget(self.pg_saxs, 1, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab1_1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setMinimumSize(QtCore.QSize(0, 100))
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_40 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_40.setObjectName("gridLayout_40")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_40.addItem(spacerItem, 0, 0, 1, 1)
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_13 = QtWidgets.QLabel(self.groupBox_3)
        self.label_13.setObjectName("label_13")
        self.gridLayout_3.addWidget(self.label_13, 0, 0, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.groupBox_3)
        self.label_12.setObjectName("label_12")
        self.gridLayout_3.addWidget(self.label_12, 0, 3, 1, 1)
        self.cb_saxs2D_type = QtWidgets.QComboBox(self.groupBox_3)
        self.cb_saxs2D_type.setObjectName("cb_saxs2D_type")
        self.cb_saxs2D_type.addItem("")
        self.cb_saxs2D_type.addItem("")
        self.gridLayout_3.addWidget(self.cb_saxs2D_type, 0, 4, 1, 2)
        self.cb_saxs2D_cmap = QtWidgets.QComboBox(self.groupBox_3)
        self.cb_saxs2D_cmap.setObjectName("cb_saxs2D_cmap")
        self.cb_saxs2D_cmap.addItem("")
        self.cb_saxs2D_cmap.addItem("")
        self.cb_saxs2D_cmap.addItem("")
        self.cb_saxs2D_cmap.addItem("")
        self.cb_saxs2D_cmap.addItem("")
        self.cb_saxs2D_cmap.addItem("")
        self.gridLayout_3.addWidget(self.cb_saxs2D_cmap, 0, 1, 1, 2)
        self.pushButton_5 = QtWidgets.QPushButton(self.groupBox_3)
        self.pushButton_5.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButton_5.setObjectName("pushButton_5")
        self.gridLayout_3.addWidget(self.pushButton_5, 0, 9, 2, 1)
        self.label_50 = QtWidgets.QLabel(self.groupBox_3)
        self.label_50.setObjectName("label_50")
        self.gridLayout_3.addWidget(self.label_50, 1, 0, 1, 1)
        self.label_51 = QtWidgets.QLabel(self.groupBox_3)
        self.label_51.setObjectName("label_51")
        self.gridLayout_3.addWidget(self.label_51, 1, 3, 1, 1)
        self.saxs2d_autorange = QtWidgets.QCheckBox(self.groupBox_3)
        self.saxs2d_autorange.setChecked(True)
        self.saxs2d_autorange.setObjectName("saxs2d_autorange")
        self.gridLayout_3.addWidget(self.saxs2d_autorange, 1, 6, 1, 3)
        self.saxs2d_autorotate = QtWidgets.QCheckBox(self.groupBox_3)
        self.saxs2d_autorotate.setChecked(True)
        self.saxs2d_autorotate.setObjectName("saxs2d_autorotate")
        self.gridLayout_3.addWidget(self.saxs2d_autorotate, 0, 6, 1, 3)
        self.saxs2d_max = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        self.saxs2d_max.setEnabled(False)
        self.saxs2d_max.setDecimals(4)
        self.saxs2d_max.setMinimum(-99.0)
        self.saxs2d_max.setMaximum(99999.0)
        self.saxs2d_max.setObjectName("saxs2d_max")
        self.gridLayout_3.addWidget(self.saxs2d_max, 1, 4, 1, 2)
        self.saxs2d_min = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        self.saxs2d_min.setEnabled(False)
        self.saxs2d_min.setDecimals(4)
        self.saxs2d_min.setMinimum(-99.0)
        self.saxs2d_min.setMaximum(99999.0)
        self.saxs2d_min.setObjectName("saxs2d_min")
        self.gridLayout_3.addWidget(self.saxs2d_min, 1, 1, 1, 2)
        self.gridLayout_40.addLayout(self.gridLayout_3, 0, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_40.addItem(spacerItem1, 0, 2, 1, 1)
        self.gridLayout_26.addWidget(self.groupBox_3, 2, 0, 1, 1)
        self.tabWidget.addTab(self.tab1_1, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.gridLayout_25 = QtWidgets.QGridLayout(self.tab_2)
        self.gridLayout_25.setObjectName("gridLayout_25")
        self.groupBox_6 = QtWidgets.QGroupBox(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_6.sizePolicy().hasHeightForWidth())
        self.groupBox_6.setSizePolicy(sizePolicy)
        self.groupBox_6.setObjectName("groupBox_6")
        self.gridLayout_16 = QtWidgets.QGridLayout(self.groupBox_6)
        self.gridLayout_16.setObjectName("gridLayout_16")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_16.addItem(spacerItem2, 0, 0, 1, 1)
        self.gridLayout_24 = QtWidgets.QGridLayout()
        self.gridLayout_24.setObjectName("gridLayout_24")
        self.saxs1d_qmax = QtWidgets.QDoubleSpinBox(self.groupBox_6)
        self.saxs1d_qmax.setDecimals(4)
        self.saxs1d_qmax.setSingleStep(0.0005)
        self.saxs1d_qmax.setProperty("value", 1.0)
        self.saxs1d_qmax.setObjectName("saxs1d_qmax")
        self.gridLayout_24.addWidget(self.saxs1d_qmax, 0, 8, 1, 1)
        self.label_23 = QtWidgets.QLabel(self.groupBox_6)
        self.label_23.setObjectName("label_23")
        self.gridLayout_24.addWidget(self.label_23, 0, 4, 1, 1)
        self.pushButton_10 = QtWidgets.QPushButton(self.groupBox_6)
        self.pushButton_10.setObjectName("pushButton_10")
        self.gridLayout_24.addWidget(self.pushButton_10, 1, 0, 1, 9)
        self.sb_saxs_offset = QtWidgets.QDoubleSpinBox(self.groupBox_6)
        self.sb_saxs_offset.setDecimals(4)
        self.sb_saxs_offset.setSingleStep(0.05)
        self.sb_saxs_offset.setProperty("value", 0.0)
        self.sb_saxs_offset.setObjectName("sb_saxs_offset")
        self.gridLayout_24.addWidget(self.sb_saxs_offset, 0, 3, 1, 1)
        self.label_22 = QtWidgets.QLabel(self.groupBox_6)
        self.label_22.setObjectName("label_22")
        self.gridLayout_24.addWidget(self.label_22, 0, 2, 1, 1)
        self.cb_saxs_type = QtWidgets.QComboBox(self.groupBox_6)
        self.cb_saxs_type.setObjectName("cb_saxs_type")
        self.cb_saxs_type.addItem("")
        self.cb_saxs_type.addItem("")
        self.cb_saxs_type.addItem("")
        self.cb_saxs_type.addItem("")
        self.gridLayout_24.addWidget(self.cb_saxs_type, 0, 1, 1, 1)
        self.label_21 = QtWidgets.QLabel(self.groupBox_6)
        self.label_21.setObjectName("label_21")
        self.gridLayout_24.addWidget(self.label_21, 0, 0, 1, 1)
        self.label_49 = QtWidgets.QLabel(self.groupBox_6)
        self.label_49.setObjectName("label_49")
        self.gridLayout_24.addWidget(self.label_49, 0, 6, 1, 1)
        self.cb_saxs_norm = QtWidgets.QComboBox(self.groupBox_6)
        self.cb_saxs_norm.setObjectName("cb_saxs_norm")
        self.cb_saxs_norm.addItem("")
        self.cb_saxs_norm.addItem("")
        self.cb_saxs_norm.addItem("")
        self.cb_saxs_norm.addItem("")
        self.gridLayout_24.addWidget(self.cb_saxs_norm, 0, 5, 1, 1)
        self.saxs1d_qmin = QtWidgets.QDoubleSpinBox(self.groupBox_6)
        self.saxs1d_qmin.setDecimals(4)
        self.saxs1d_qmin.setSingleStep(0.002)
        self.saxs1d_qmin.setObjectName("saxs1d_qmin")
        self.gridLayout_24.addWidget(self.saxs1d_qmin, 0, 7, 1, 1)
        self.gridLayout_16.addLayout(self.gridLayout_24, 0, 1, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_16.addItem(spacerItem3, 0, 2, 1, 1)
        self.gridLayout_25.addWidget(self.groupBox_6, 1, 0, 1, 1)
        self.mp_saxs = MplCanvasBarV(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mp_saxs.sizePolicy().hasHeightForWidth())
        self.mp_saxs.setSizePolicy(sizePolicy)
        self.mp_saxs.setMinimumSize(QtCore.QSize(600, 0))
        self.mp_saxs.setObjectName("mp_saxs")
        self.gridLayout_25.addWidget(self.mp_saxs, 0, 0, 1, 1)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.tab_3)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.mp_stab = MplCanvasBarV(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mp_stab.sizePolicy().hasHeightForWidth())
        self.mp_stab.setSizePolicy(sizePolicy)
        self.mp_stab.setObjectName("mp_stab")
        self.gridLayout_6.addWidget(self.mp_stab, 0, 0, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_4.sizePolicy().hasHeightForWidth())
        self.groupBox_4.setSizePolicy(sizePolicy)
        self.groupBox_4.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_20 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_20.setObjectName("gridLayout_20")
        spacerItem4 = QtWidgets.QSpacerItem(235, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_20.addItem(spacerItem4, 0, 0, 1, 1)
        self.gridLayout_17 = QtWidgets.QGridLayout()
        self.gridLayout_17.setObjectName("gridLayout_17")
        self.label_14 = QtWidgets.QLabel(self.groupBox_4)
        self.label_14.setObjectName("label_14")
        self.gridLayout_17.addWidget(self.label_14, 0, 0, 1, 1)
        self.cb_stab_type = QtWidgets.QComboBox(self.groupBox_4)
        self.cb_stab_type.setObjectName("cb_stab_type")
        self.cb_stab_type.addItem("")
        self.cb_stab_type.addItem("")
        self.cb_stab_type.addItem("")
        self.cb_stab_type.addItem("")
        self.gridLayout_17.addWidget(self.cb_stab_type, 0, 1, 1, 1)
        self.label_24 = QtWidgets.QLabel(self.groupBox_4)
        self.label_24.setObjectName("label_24")
        self.gridLayout_17.addWidget(self.label_24, 0, 2, 1, 1)
        self.sb_stab_offset = QtWidgets.QDoubleSpinBox(self.groupBox_4)
        self.sb_stab_offset.setDecimals(4)
        self.sb_stab_offset.setSingleStep(0.05)
        self.sb_stab_offset.setProperty("value", 0.0)
        self.sb_stab_offset.setObjectName("sb_stab_offset")
        self.gridLayout_17.addWidget(self.sb_stab_offset, 0, 3, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.groupBox_4)
        self.label_16.setObjectName("label_16")
        self.gridLayout_17.addWidget(self.label_16, 0, 4, 1, 2)
        self.pushButton_7 = QtWidgets.QPushButton(self.groupBox_4)
        self.pushButton_7.setObjectName("pushButton_7")
        self.gridLayout_17.addWidget(self.pushButton_7, 1, 6, 1, 1)
        self.cb_stab = QtWidgets.QComboBox(self.groupBox_4)
        self.cb_stab.setObjectName("cb_stab")
        self.gridLayout_17.addWidget(self.cb_stab, 1, 0, 1, 6)
        self.cb_stab_norm = QtWidgets.QComboBox(self.groupBox_4)
        self.cb_stab_norm.setObjectName("cb_stab_norm")
        self.cb_stab_norm.addItem("")
        self.cb_stab_norm.addItem("")
        self.cb_stab_norm.addItem("")
        self.cb_stab_norm.addItem("")
        self.gridLayout_17.addWidget(self.cb_stab_norm, 0, 6, 1, 1)
        self.gridLayout_20.addLayout(self.gridLayout_17, 0, 1, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_20.addItem(spacerItem5, 0, 2, 1, 1)
        self.gridLayout_6.addWidget(self.groupBox_4, 1, 0, 1, 1)
        self.tabWidget.addTab(self.tab_3, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.gridLayout_27 = QtWidgets.QGridLayout(self.tab_4)
        self.gridLayout_27.setObjectName("gridLayout_27")
        self.pg_intt = PlotWidgetDev(self.tab_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pg_intt.sizePolicy().hasHeightForWidth())
        self.pg_intt.setSizePolicy(sizePolicy)
        self.pg_intt.setObjectName("pg_intt")
        self.gridLayout_27.addWidget(self.pg_intt, 0, 0, 1, 3)
        spacerItem6 = QtWidgets.QSpacerItem(581, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_27.addItem(spacerItem6, 1, 0, 1, 1)
        self.groupBox_7 = QtWidgets.QGroupBox(self.tab_4)
        self.groupBox_7.setObjectName("groupBox_7")
        self.gridLayout_23 = QtWidgets.QGridLayout(self.groupBox_7)
        self.gridLayout_23.setObjectName("gridLayout_23")
        self.label_9 = QtWidgets.QLabel(self.groupBox_7)
        self.label_9.setObjectName("label_9")
        self.gridLayout_23.addWidget(self.label_9, 0, 0, 1, 1)
        self.label_34 = QtWidgets.QLabel(self.groupBox_7)
        self.label_34.setObjectName("label_34")
        self.gridLayout_23.addWidget(self.label_34, 0, 6, 1, 1)
        self.label_31 = QtWidgets.QLabel(self.groupBox_7)
        self.label_31.setObjectName("label_31")
        self.gridLayout_23.addWidget(self.label_31, 0, 2, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.groupBox_7)
        self.label_11.setObjectName("label_11")
        self.gridLayout_23.addWidget(self.label_11, 0, 4, 1, 1)
        self.sb_intt_max = QtWidgets.QSpinBox(self.groupBox_7)
        self.sb_intt_max.setProperty("value", 10)
        self.sb_intt_max.setObjectName("sb_intt_max")
        self.gridLayout_23.addWidget(self.sb_intt_max, 0, 1, 1, 1)
        self.sb_window = QtWidgets.QSpinBox(self.groupBox_7)
        self.sb_window.setMaximum(999)
        self.sb_window.setProperty("value", 1)
        self.sb_window.setObjectName("sb_window")
        self.gridLayout_23.addWidget(self.sb_window, 0, 3, 1, 1)
        self.sb_intt_sampling = QtWidgets.QSpinBox(self.groupBox_7)
        self.sb_intt_sampling.setProperty("value", 2)
        self.sb_intt_sampling.setObjectName("sb_intt_sampling")
        self.gridLayout_23.addWidget(self.sb_intt_sampling, 0, 5, 1, 1)
        self.intt_xlabel = QtWidgets.QComboBox(self.groupBox_7)
        self.intt_xlabel.setObjectName("intt_xlabel")
        self.intt_xlabel.addItem("")
        self.intt_xlabel.addItem("")
        self.gridLayout_23.addWidget(self.intt_xlabel, 0, 7, 1, 1)
        self.btn_intt = QtWidgets.QPushButton(self.groupBox_7)
        self.btn_intt.setObjectName("btn_intt")
        self.gridLayout_23.addWidget(self.btn_intt, 1, 0, 1, 8)
        self.gridLayout_27.addWidget(self.groupBox_7, 1, 1, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(580, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_27.addItem(spacerItem7, 1, 2, 1, 1)
        self.tabWidget.addTab(self.tab_4, "")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.gridLayout_36 = QtWidgets.QGridLayout(self.tab_5)
        self.gridLayout_36.setObjectName("gridLayout_36")
        self.groupBox_10 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_10.setObjectName("groupBox_10")
        self.gridLayout_31 = QtWidgets.QGridLayout(self.groupBox_10)
        self.gridLayout_31.setObjectName("gridLayout_31")
        self.mp_avg_g2 = PlotWidgetDev(self.groupBox_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mp_avg_g2.sizePolicy().hasHeightForWidth())
        self.mp_avg_g2.setSizePolicy(sizePolicy)
        self.mp_avg_g2.setMinimumSize(QtCore.QSize(0, 300))
        self.mp_avg_g2.setObjectName("mp_avg_g2")
        self.gridLayout_31.addWidget(self.mp_avg_g2, 0, 0, 1, 1)
        self.gridLayout_36.addWidget(self.groupBox_10, 0, 0, 1, 3)
        self.groupBox_8 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_8.setObjectName("groupBox_8")
        self.gridLayout_30 = QtWidgets.QGridLayout(self.groupBox_8)
        self.gridLayout_30.setObjectName("gridLayout_30")
        self.gridLayout_28 = QtWidgets.QGridLayout()
        self.gridLayout_28.setObjectName("gridLayout_28")
        self.max_thread_count = QtWidgets.QSpinBox(self.groupBox_8)
        self.max_thread_count.setMinimum(1)
        self.max_thread_count.setMaximum(32)
        self.max_thread_count.setSingleStep(1)
        self.max_thread_count.setProperty("value", 4)
        self.max_thread_count.setObjectName("max_thread_count")
        self.gridLayout_28.addWidget(self.max_thread_count, 0, 5, 1, 2)
        self.avg_blmax = QtWidgets.QDoubleSpinBox(self.groupBox_8)
        self.avg_blmax.setDecimals(3)
        self.avg_blmax.setMinimum(0.9)
        self.avg_blmax.setMaximum(10.0)
        self.avg_blmax.setSingleStep(0.01)
        self.avg_blmax.setProperty("value", 1.05)
        self.avg_blmax.setObjectName("avg_blmax")
        self.gridLayout_28.addWidget(self.avg_blmax, 2, 5, 1, 2)
        self.avg_blmin = QtWidgets.QDoubleSpinBox(self.groupBox_8)
        self.avg_blmin.setSpecialValueText("")
        self.avg_blmin.setDecimals(3)
        self.avg_blmin.setMaximum(10.0)
        self.avg_blmin.setSingleStep(0.01)
        self.avg_blmin.setProperty("value", 0.95)
        self.avg_blmin.setObjectName("avg_blmin")
        self.gridLayout_28.addWidget(self.avg_blmin, 2, 1, 1, 2)
        self.avg_save_path = QtWidgets.QLineEdit(self.groupBox_8)
        self.avg_save_path.setClearButtonEnabled(True)
        self.avg_save_path.setObjectName("avg_save_path")
        self.gridLayout_28.addWidget(self.avg_save_path, 6, 2, 1, 4)
        self.label_39 = QtWidgets.QLabel(self.groupBox_8)
        self.label_39.setObjectName("label_39")
        self.gridLayout_28.addWidget(self.label_39, 2, 4, 1, 1)
        self.cb_avg_chunk_size = QtWidgets.QComboBox(self.groupBox_8)
        self.cb_avg_chunk_size.setMaximumSize(QtCore.QSize(80, 16777215))
        self.cb_avg_chunk_size.setObjectName("cb_avg_chunk_size")
        self.cb_avg_chunk_size.addItem("")
        self.cb_avg_chunk_size.addItem("")
        self.cb_avg_chunk_size.addItem("")
        self.cb_avg_chunk_size.addItem("")
        self.cb_avg_chunk_size.addItem("")
        self.gridLayout_28.addWidget(self.cb_avg_chunk_size, 0, 2, 1, 1)
        self.btn_set_average_save_name = QtWidgets.QPushButton(self.groupBox_8)
        self.btn_set_average_save_name.setMinimumSize(QtCore.QSize(10, 0))
        self.btn_set_average_save_name.setObjectName("btn_set_average_save_name")
        self.gridLayout_28.addWidget(self.btn_set_average_save_name, 7, 6, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.groupBox_8)
        self.label_17.setObjectName("label_17")
        self.gridLayout_28.addWidget(self.label_17, 0, 0, 1, 2)
        self.label_32 = QtWidgets.QLabel(self.groupBox_8)
        self.label_32.setObjectName("label_32")
        self.gridLayout_28.addWidget(self.label_32, 1, 0, 1, 1)
        self.label_25 = QtWidgets.QLabel(self.groupBox_8)
        self.label_25.setObjectName("label_25")
        self.gridLayout_28.addWidget(self.label_25, 2, 0, 1, 1)
        self.label_19 = QtWidgets.QLabel(self.groupBox_8)
        self.label_19.setObjectName("label_19")
        self.gridLayout_28.addWidget(self.label_19, 7, 0, 1, 2)
        self.bx_avg_G2IPIF = QtWidgets.QCheckBox(self.groupBox_8)
        self.bx_avg_G2IPIF.setObjectName("bx_avg_G2IPIF")
        self.gridLayout_28.addWidget(self.bx_avg_G2IPIF, 3, 5, 3, 2)
        self.avg_window = QtWidgets.QSpinBox(self.groupBox_8)
        self.avg_window.setMinimum(1)
        self.avg_window.setProperty("value", 10)
        self.avg_window.setObjectName("avg_window")
        self.gridLayout_28.addWidget(self.avg_window, 1, 5, 1, 2)
        self.bx_avg_g2g2err = QtWidgets.QCheckBox(self.groupBox_8)
        self.bx_avg_g2g2err.setChecked(True)
        self.bx_avg_g2g2err.setObjectName("bx_avg_g2g2err")
        self.gridLayout_28.addWidget(self.bx_avg_g2g2err, 3, 4, 3, 1)
        self.avg_save_name = QtWidgets.QLineEdit(self.groupBox_8)
        self.avg_save_name.setClearButtonEnabled(True)
        self.avg_save_name.setObjectName("avg_save_name")
        self.gridLayout_28.addWidget(self.avg_save_name, 7, 2, 1, 4)
        self.label_20 = QtWidgets.QLabel(self.groupBox_8)
        self.label_20.setObjectName("label_20")
        self.gridLayout_28.addWidget(self.label_20, 6, 0, 1, 2)
        self.btn_set_average_save_path = QtWidgets.QPushButton(self.groupBox_8)
        self.btn_set_average_save_path.setMinimumSize(QtCore.QSize(10, 0))
        self.btn_set_average_save_path.setObjectName("btn_set_average_save_path")
        self.gridLayout_28.addWidget(self.btn_set_average_save_path, 6, 6, 1, 1)
        self.bx_avg_saxs = QtWidgets.QCheckBox(self.groupBox_8)
        self.bx_avg_saxs.setChecked(True)
        self.bx_avg_saxs.setObjectName("bx_avg_saxs")
        self.gridLayout_28.addWidget(self.bx_avg_saxs, 3, 3, 3, 1)
        self.label_26 = QtWidgets.QLabel(self.groupBox_8)
        self.label_26.setObjectName("label_26")
        self.gridLayout_28.addWidget(self.label_26, 3, 0, 3, 3)
        self.label_33 = QtWidgets.QLabel(self.groupBox_8)
        self.label_33.setObjectName("label_33")
        self.gridLayout_28.addWidget(self.label_33, 1, 4, 1, 1)
        self.label_40 = QtWidgets.QLabel(self.groupBox_8)
        self.label_40.setObjectName("label_40")
        self.gridLayout_28.addWidget(self.label_40, 0, 4, 1, 1)
        self.avg_qindex = QtWidgets.QSpinBox(self.groupBox_8)
        self.avg_qindex.setMaximum(999)
        self.avg_qindex.setProperty("value", 5)
        self.avg_qindex.setObjectName("avg_qindex")
        self.gridLayout_28.addWidget(self.avg_qindex, 1, 1, 1, 2)
        self.gridLayout_30.addLayout(self.gridLayout_28, 0, 0, 1, 1)
        self.gridLayout_36.addWidget(self.groupBox_8, 1, 0, 1, 1)
        self.groupBox_12 = QtWidgets.QGroupBox(self.tab_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_12.sizePolicy().hasHeightForWidth())
        self.groupBox_12.setSizePolicy(sizePolicy)
        self.groupBox_12.setObjectName("groupBox_12")
        self.gridLayout_35 = QtWidgets.QGridLayout(self.groupBox_12)
        self.gridLayout_35.setObjectName("gridLayout_35")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.btn_submit_job = QtWidgets.QPushButton(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btn_submit_job.sizePolicy().hasHeightForWidth())
        self.btn_submit_job.setSizePolicy(sizePolicy)
        self.btn_submit_job.setObjectName("btn_submit_job")
        self.verticalLayout_3.addWidget(self.btn_submit_job)
        self.avg_job_pop = QtWidgets.QPushButton(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.avg_job_pop.sizePolicy().hasHeightForWidth())
        self.avg_job_pop.setSizePolicy(sizePolicy)
        self.avg_job_pop.setObjectName("avg_job_pop")
        self.verticalLayout_3.addWidget(self.avg_job_pop)
        self.btn_avg_jobinfo = QtWidgets.QPushButton(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btn_avg_jobinfo.sizePolicy().hasHeightForWidth())
        self.btn_avg_jobinfo.setSizePolicy(sizePolicy)
        self.btn_avg_jobinfo.setObjectName("btn_avg_jobinfo")
        self.verticalLayout_3.addWidget(self.btn_avg_jobinfo)
        self.btn_avg_kill = QtWidgets.QPushButton(self.groupBox_12)
        self.btn_avg_kill.setObjectName("btn_avg_kill")
        self.verticalLayout_3.addWidget(self.btn_avg_kill)
        self.btn_start_avg_job = QtWidgets.QPushButton(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btn_start_avg_job.sizePolicy().hasHeightForWidth())
        self.btn_start_avg_job.setSizePolicy(sizePolicy)
        self.btn_start_avg_job.setObjectName("btn_start_avg_job")
        self.verticalLayout_3.addWidget(self.btn_start_avg_job)
        self.gridLayout_35.addLayout(self.verticalLayout_3, 0, 0, 1, 1)
        self.gridLayout_36.addWidget(self.groupBox_12, 1, 1, 1, 1)
        self.groupBox_9 = QtWidgets.QGroupBox(self.tab_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_9.sizePolicy().hasHeightForWidth())
        self.groupBox_9.setSizePolicy(sizePolicy)
        self.groupBox_9.setObjectName("groupBox_9")
        self.gridLayout_29 = QtWidgets.QGridLayout(self.groupBox_9)
        self.gridLayout_29.setObjectName("gridLayout_29")
        self.avg_job_table = QtWidgets.QTableView(self.groupBox_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.avg_job_table.sizePolicy().hasHeightForWidth())
        self.avg_job_table.setSizePolicy(sizePolicy)
        self.avg_job_table.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.avg_job_table.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.avg_job_table.setObjectName("avg_job_table")
        self.avg_job_table.horizontalHeader().setDefaultSectionSize(100)
        self.avg_job_table.horizontalHeader().setMinimumSectionSize(19)
        self.avg_job_table.horizontalHeader().setStretchLastSection(True)
        self.avg_job_table.verticalHeader().setDefaultSectionSize(30)
        self.gridLayout_29.addWidget(self.avg_job_table, 0, 0, 1, 2)
        self.gridLayout_36.addWidget(self.groupBox_9, 1, 2, 1, 1)
        self.tabWidget.addTab(self.tab_5, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.tab_6)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.scrollArea = QtWidgets.QScrollArea(self.tab_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(30)
        sizePolicy.setHeightForWidth(self.scrollArea.sizePolicy().hasHeightForWidth())
        self.scrollArea.setSizePolicy(sizePolicy)
        self.scrollArea.setMinimumSize(QtCore.QSize(0, 0))
        self.scrollArea.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.scrollArea.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.g2_scroll_area = QtWidgets.QWidget()
        self.g2_scroll_area.setGeometry(QtCore.QRect(0, 0, 1524, 729))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.g2_scroll_area.sizePolicy().hasHeightForWidth())
        self.g2_scroll_area.setSizePolicy(sizePolicy)
        self.g2_scroll_area.setObjectName("g2_scroll_area")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.g2_scroll_area)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.mp_g2 = PlotWidgetDev(self.g2_scroll_area)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mp_g2.sizePolicy().hasHeightForWidth())
        self.mp_g2.setSizePolicy(sizePolicy)
        self.mp_g2.setMinimumSize(QtCore.QSize(0, 0))
        self.mp_g2.setObjectName("mp_g2")
        self.gridLayout_10.addWidget(self.mp_g2, 0, 0, 1, 1)
        self.scrollArea.setWidget(self.g2_scroll_area)
        self.gridLayout_9.addWidget(self.scrollArea, 0, 0, 1, 1)
        self.gridLayout_8 = QtWidgets.QGridLayout()
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.groupBox = QtWidgets.QGroupBox(self.tab_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox.setMaximumSize(QtCore.QSize(16777215, 65536))
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_13 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_13.setObjectName("gridLayout_13")
        self.gridLayout_11 = QtWidgets.QGridLayout()
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.gridLayout_11.addWidget(self.label_4, 1, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.gridLayout_11.addWidget(self.label_3, 0, 0, 1, 1)
        self.g2_ymin = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.g2_ymin.sizePolicy().hasHeightForWidth())
        self.g2_ymin.setSizePolicy(sizePolicy)
        self.g2_ymin.setObjectName("g2_ymin")
        self.gridLayout_11.addWidget(self.g2_ymin, 2, 1, 1, 1)
        self.g2_qmin = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.g2_qmin.sizePolicy().hasHeightForWidth())
        self.g2_qmin.setSizePolicy(sizePolicy)
        self.g2_qmin.setObjectName("g2_qmin")
        self.gridLayout_11.addWidget(self.g2_qmin, 0, 1, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.groupBox)
        self.label_7.setObjectName("label_7")
        self.gridLayout_11.addWidget(self.label_7, 2, 0, 1, 1)
        self.g2_tmin = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.g2_tmin.sizePolicy().hasHeightForWidth())
        self.g2_tmin.setSizePolicy(sizePolicy)
        self.g2_tmin.setObjectName("g2_tmin")
        self.gridLayout_11.addWidget(self.g2_tmin, 1, 1, 1, 1)
        self.g2_qmax = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.g2_qmax.sizePolicy().hasHeightForWidth())
        self.g2_qmax.setSizePolicy(sizePolicy)
        self.g2_qmax.setObjectName("g2_qmax")
        self.gridLayout_11.addWidget(self.g2_qmax, 0, 2, 1, 1)
        self.g2_tmax = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.g2_tmax.sizePolicy().hasHeightForWidth())
        self.g2_tmax.setSizePolicy(sizePolicy)
        self.g2_tmax.setObjectName("g2_tmax")
        self.gridLayout_11.addWidget(self.g2_tmax, 1, 2, 1, 1)
        self.g2_ymax = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.g2_ymax.sizePolicy().hasHeightForWidth())
        self.g2_ymax.setSizePolicy(sizePolicy)
        self.g2_ymax.setObjectName("g2_ymax")
        self.gridLayout_11.addWidget(self.g2_ymax, 2, 2, 1, 1)
        self.g2_yauto = QtWidgets.QCheckBox(self.groupBox)
        self.g2_yauto.setObjectName("g2_yauto")
        self.gridLayout_11.addWidget(self.g2_yauto, 2, 3, 1, 1)
        self.gridLayout_13.addLayout(self.gridLayout_11, 0, 1, 1, 1)
        self.gridLayout_19 = QtWidgets.QGridLayout()
        self.gridLayout_19.setObjectName("gridLayout_19")
        self.label_8 = QtWidgets.QLabel(self.groupBox)
        self.label_8.setObjectName("label_8")
        self.gridLayout_19.addWidget(self.label_8, 1, 0, 1, 1)
        self.sb_g2_column = QtWidgets.QSpinBox(self.groupBox)
        self.sb_g2_column.setMinimum(1)
        self.sb_g2_column.setMaximum(8)
        self.sb_g2_column.setSingleStep(1)
        self.sb_g2_column.setProperty("value", 4)
        self.sb_g2_column.setObjectName("sb_g2_column")
        self.gridLayout_19.addWidget(self.sb_g2_column, 1, 1, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.gridLayout_19.addWidget(self.label, 2, 0, 1, 1)
        self.sb_g2_offset = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.sb_g2_offset.setDecimals(3)
        self.sb_g2_offset.setSingleStep(0.005)
        self.sb_g2_offset.setObjectName("sb_g2_offset")
        self.gridLayout_19.addWidget(self.sb_g2_offset, 2, 1, 1, 1)
        self.g2_show_fit = QtWidgets.QCheckBox(self.groupBox)
        self.g2_show_fit.setChecked(False)
        self.g2_show_fit.setObjectName("g2_show_fit")
        self.gridLayout_19.addWidget(self.g2_show_fit, 2, 2, 1, 1)
        self.pushButton_4 = QtWidgets.QPushButton(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_4.sizePolicy().hasHeightForWidth())
        self.pushButton_4.setSizePolicy(sizePolicy)
        self.pushButton_4.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButton_4.setObjectName("pushButton_4")
        self.gridLayout_19.addWidget(self.pushButton_4, 0, 0, 1, 2)
        self.g2_sub_baseline = QtWidgets.QCheckBox(self.groupBox)
        self.g2_sub_baseline.setChecked(False)
        self.g2_sub_baseline.setObjectName("g2_sub_baseline")
        self.gridLayout_19.addWidget(self.g2_sub_baseline, 2, 3, 1, 1)
        self.g2_show_label = QtWidgets.QCheckBox(self.groupBox)
        self.g2_show_label.setChecked(False)
        self.g2_show_label.setObjectName("g2_show_label")
        self.gridLayout_19.addWidget(self.g2_show_label, 1, 2, 1, 2)
        self.g2_plot_type = QtWidgets.QComboBox(self.groupBox)
        self.g2_plot_type.setObjectName("g2_plot_type")
        self.g2_plot_type.addItem("")
        self.g2_plot_type.addItem("")
        self.g2_plot_type.addItem("")
        self.gridLayout_19.addWidget(self.g2_plot_type, 0, 2, 1, 2)
        self.gridLayout_13.addLayout(self.gridLayout_19, 0, 0, 1, 1)
        self.gridLayout_8.addWidget(self.groupBox, 0, 0, 1, 1)
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_2.setMaximumSize(QtCore.QSize(16777215, 65536))
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_14 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.show_g2_fit_summary = QtWidgets.QPushButton(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.show_g2_fit_summary.sizePolicy().hasHeightForWidth())
        self.show_g2_fit_summary.setSizePolicy(sizePolicy)
        self.show_g2_fit_summary.setObjectName("show_g2_fit_summary")
        self.gridLayout_14.addWidget(self.show_g2_fit_summary, 0, 1, 1, 1)
        self.btn_g2_refit = QtWidgets.QPushButton(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btn_g2_refit.sizePolicy().hasHeightForWidth())
        self.btn_g2_refit.setSizePolicy(sizePolicy)
        self.btn_g2_refit.setObjectName("btn_g2_refit")
        self.gridLayout_14.addWidget(self.btn_g2_refit, 2, 1, 1, 1)
        self.gridLayout_12 = QtWidgets.QGridLayout()
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.label_45 = QtWidgets.QLabel(self.groupBox_2)
        self.label_45.setObjectName("label_45")
        self.gridLayout_12.addWidget(self.label_45, 0, 0, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_2)
        self.label_5.setObjectName("label_5")
        self.gridLayout_12.addWidget(self.label_5, 0, 1, 1, 1)
        self.g2_amin = QtWidgets.QLineEdit(self.groupBox_2)
        self.g2_amin.setObjectName("g2_amin")
        self.gridLayout_12.addWidget(self.g2_amin, 0, 2, 1, 1)
        self.g2_amax = QtWidgets.QLineEdit(self.groupBox_2)
        self.g2_amax.setObjectName("g2_amax")
        self.gridLayout_12.addWidget(self.g2_amax, 0, 3, 1, 1)
        self.g2_afit = QtWidgets.QCheckBox(self.groupBox_2)
        self.g2_afit.setChecked(True)
        self.g2_afit.setObjectName("g2_afit")
        self.gridLayout_12.addWidget(self.g2_afit, 0, 4, 1, 1)
        self.label_46 = QtWidgets.QLabel(self.groupBox_2)
        self.label_46.setObjectName("label_46")
        self.gridLayout_12.addWidget(self.label_46, 1, 0, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_2)
        self.label_6.setObjectName("label_6")
        self.gridLayout_12.addWidget(self.label_6, 1, 1, 1, 1)
        self.g2_bmin = QtWidgets.QLineEdit(self.groupBox_2)
        self.g2_bmin.setObjectName("g2_bmin")
        self.gridLayout_12.addWidget(self.g2_bmin, 1, 2, 1, 1)
        self.g2_bmax = QtWidgets.QLineEdit(self.groupBox_2)
        self.g2_bmax.setObjectName("g2_bmax")
        self.gridLayout_12.addWidget(self.g2_bmax, 1, 3, 1, 1)
        self.g2_bfit = QtWidgets.QCheckBox(self.groupBox_2)
        self.g2_bfit.setChecked(True)
        self.g2_bfit.setObjectName("g2_bfit")
        self.gridLayout_12.addWidget(self.g2_bfit, 1, 4, 1, 1)
        self.label_47 = QtWidgets.QLabel(self.groupBox_2)
        self.label_47.setObjectName("label_47")
        self.gridLayout_12.addWidget(self.label_47, 2, 0, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.groupBox_2)
        self.label_10.setObjectName("label_10")
        self.gridLayout_12.addWidget(self.label_10, 2, 1, 1, 1)
        self.g2_cmin = QtWidgets.QLineEdit(self.groupBox_2)
        self.g2_cmin.setObjectName("g2_cmin")
        self.gridLayout_12.addWidget(self.g2_cmin, 2, 2, 1, 1)
        self.g2_cmax = QtWidgets.QLineEdit(self.groupBox_2)
        self.g2_cmax.setObjectName("g2_cmax")
        self.gridLayout_12.addWidget(self.g2_cmax, 2, 3, 1, 1)
        self.g2_cfit = QtWidgets.QCheckBox(self.groupBox_2)
        self.g2_cfit.setChecked(True)
        self.g2_cfit.setObjectName("g2_cfit")
        self.gridLayout_12.addWidget(self.g2_cfit, 2, 4, 1, 1)
        self.label_48 = QtWidgets.QLabel(self.groupBox_2)
        self.label_48.setObjectName("label_48")
        self.gridLayout_12.addWidget(self.label_48, 3, 0, 1, 1)
        self.label_41 = QtWidgets.QLabel(self.groupBox_2)
        self.label_41.setObjectName("label_41")
        self.gridLayout_12.addWidget(self.label_41, 3, 1, 1, 1)
        self.g2_dmin = QtWidgets.QLineEdit(self.groupBox_2)
        self.g2_dmin.setObjectName("g2_dmin")
        self.gridLayout_12.addWidget(self.g2_dmin, 3, 2, 1, 1)
        self.g2_dmax = QtWidgets.QLineEdit(self.groupBox_2)
        self.g2_dmax.setObjectName("g2_dmax")
        self.gridLayout_12.addWidget(self.g2_dmax, 3, 3, 1, 1)
        self.g2_dfit = QtWidgets.QCheckBox(self.groupBox_2)
        self.g2_dfit.setChecked(True)
        self.g2_dfit.setObjectName("g2_dfit")
        self.gridLayout_12.addWidget(self.g2_dfit, 3, 4, 1, 1)
        self.gridLayout_14.addLayout(self.gridLayout_12, 0, 0, 3, 1)
        self.btn_g2_export = QtWidgets.QPushButton(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btn_g2_export.sizePolicy().hasHeightForWidth())
        self.btn_g2_export.setSizePolicy(sizePolicy)
        self.btn_g2_export.setObjectName("btn_g2_export")
        self.gridLayout_14.addWidget(self.btn_g2_export, 1, 1, 1, 1)
        self.gridLayout_8.addWidget(self.groupBox_2, 0, 1, 1, 1)
        self.gridLayout_9.addLayout(self.gridLayout_8, 1, 0, 1, 1)
        self.tabWidget.addTab(self.tab_6, "")
        self.tab_7 = QtWidgets.QWidget()
        self.tab_7.setObjectName("tab_7")
        self.gridLayout_22 = QtWidgets.QGridLayout(self.tab_7)
        self.gridLayout_22.setObjectName("gridLayout_22")
        self.mp_tauq = MplCanvasBarV(self.tab_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mp_tauq.sizePolicy().hasHeightForWidth())
        self.mp_tauq.setSizePolicy(sizePolicy)
        self.mp_tauq.setObjectName("mp_tauq")
        self.gridLayout_22.addWidget(self.mp_tauq, 0, 0, 1, 1)
        self.mp_tauq_pre = MplCanvasBarV(self.tab_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mp_tauq_pre.sizePolicy().hasHeightForWidth())
        self.mp_tauq_pre.setSizePolicy(sizePolicy)
        self.mp_tauq_pre.setObjectName("mp_tauq_pre")
        self.gridLayout_22.addWidget(self.mp_tauq_pre, 0, 1, 1, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.tab_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_5.sizePolicy().hasHeightForWidth())
        self.groupBox_5.setSizePolicy(sizePolicy)
        self.groupBox_5.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_5.setMaximumSize(QtCore.QSize(16777215, 65536))
        self.groupBox_5.setObjectName("groupBox_5")
        self.gridLayout_39 = QtWidgets.QGridLayout(self.groupBox_5)
        self.gridLayout_39.setObjectName("gridLayout_39")
        self.gridLayout_38 = QtWidgets.QGridLayout()
        self.gridLayout_38.setObjectName("gridLayout_38")
        self.gridLayout_15 = QtWidgets.QGridLayout()
        self.gridLayout_15.setObjectName("gridLayout_15")
        self.label_15 = QtWidgets.QLabel(self.groupBox_5)
        self.label_15.setObjectName("label_15")
        self.gridLayout_15.addWidget(self.label_15, 0, 0, 1, 1)
        self.cb_tauq_type = QtWidgets.QComboBox(self.groupBox_5)
        self.cb_tauq_type.setObjectName("cb_tauq_type")
        self.cb_tauq_type.addItem("")
        self.cb_tauq_type.addItem("")
        self.cb_tauq_type.addItem("")
        self.cb_tauq_type.addItem("")
        self.gridLayout_15.addWidget(self.cb_tauq_type, 0, 1, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.groupBox_5)
        self.label_18.setObjectName("label_18")
        self.gridLayout_15.addWidget(self.label_18, 1, 0, 1, 1)
        self.sb_tauq_offset = QtWidgets.QDoubleSpinBox(self.groupBox_5)
        self.sb_tauq_offset.setMinimum(-2.0)
        self.sb_tauq_offset.setMaximum(2.0)
        self.sb_tauq_offset.setSingleStep(0.2)
        self.sb_tauq_offset.setProperty("value", 0.0)
        self.sb_tauq_offset.setObjectName("sb_tauq_offset")
        self.gridLayout_15.addWidget(self.sb_tauq_offset, 1, 1, 1, 1)
        self.gridLayout_38.addLayout(self.gridLayout_15, 1, 1, 1, 1)
        self.gridLayout_21 = QtWidgets.QGridLayout()
        self.gridLayout_21.setObjectName("gridLayout_21")
        self.tauq_amax = QtWidgets.QLineEdit(self.groupBox_5)
        self.tauq_amax.setObjectName("tauq_amax")
        self.gridLayout_21.addWidget(self.tauq_amax, 0, 2, 1, 1)
        self.tauq_qmax = QtWidgets.QLineEdit(self.groupBox_5)
        self.tauq_qmax.setObjectName("tauq_qmax")
        self.gridLayout_21.addWidget(self.tauq_qmax, 2, 2, 1, 1)
        self.tauq_bfit = QtWidgets.QCheckBox(self.groupBox_5)
        self.tauq_bfit.setChecked(True)
        self.tauq_bfit.setObjectName("tauq_bfit")
        self.gridLayout_21.addWidget(self.tauq_bfit, 1, 3, 1, 1)
        self.label_44 = QtWidgets.QLabel(self.groupBox_5)
        self.label_44.setObjectName("label_44")
        self.gridLayout_21.addWidget(self.label_44, 0, 0, 1, 1)
        self.tauq_bmin = QtWidgets.QLineEdit(self.groupBox_5)
        self.tauq_bmin.setObjectName("tauq_bmin")
        self.gridLayout_21.addWidget(self.tauq_bmin, 1, 1, 1, 1)
        self.label_42 = QtWidgets.QLabel(self.groupBox_5)
        self.label_42.setObjectName("label_42")
        self.gridLayout_21.addWidget(self.label_42, 1, 0, 1, 1)
        self.tauq_amin = QtWidgets.QLineEdit(self.groupBox_5)
        self.tauq_amin.setObjectName("tauq_amin")
        self.gridLayout_21.addWidget(self.tauq_amin, 0, 1, 1, 1)
        self.tauq_afit = QtWidgets.QCheckBox(self.groupBox_5)
        self.tauq_afit.setChecked(True)
        self.tauq_afit.setObjectName("tauq_afit")
        self.gridLayout_21.addWidget(self.tauq_afit, 0, 3, 1, 1)
        self.tauq_bmax = QtWidgets.QLineEdit(self.groupBox_5)
        self.tauq_bmax.setObjectName("tauq_bmax")
        self.gridLayout_21.addWidget(self.tauq_bmax, 1, 2, 1, 1)
        self.tauq_qmin = QtWidgets.QLineEdit(self.groupBox_5)
        self.tauq_qmin.setObjectName("tauq_qmin")
        self.gridLayout_21.addWidget(self.tauq_qmin, 2, 1, 1, 1)
        self.label_43 = QtWidgets.QLabel(self.groupBox_5)
        self.label_43.setObjectName("label_43")
        self.gridLayout_21.addWidget(self.label_43, 2, 0, 1, 1)
        self.gridLayout_38.addLayout(self.gridLayout_21, 0, 0, 1, 2)
        self.pushButton_8 = QtWidgets.QPushButton(self.groupBox_5)
        self.pushButton_8.setMinimumSize(QtCore.QSize(120, 80))
        self.pushButton_8.setObjectName("pushButton_8")
        self.gridLayout_38.addWidget(self.pushButton_8, 1, 0, 1, 1)
        self.gridLayout_39.addLayout(self.gridLayout_38, 0, 0, 1, 1)
        self.tauq_msg = DataTreeWidget(self.groupBox_5)
        self.tauq_msg.setObjectName("tauq_msg")
        self.gridLayout_39.addWidget(self.tauq_msg, 0, 1, 1, 1)
        self.gridLayout_22.addWidget(self.groupBox_5, 1, 0, 1, 2)
        self.tabWidget.addTab(self.tab_7, "")
        self.tab_8 = QtWidgets.QWidget()
        self.tab_8.setObjectName("tab_8")
        self.gridLayout_33 = QtWidgets.QGridLayout(self.tab_8)
        self.gridLayout_33.setObjectName("gridLayout_33")
        self.splitter_5 = QtWidgets.QSplitter(self.tab_8)
        self.splitter_5.setOrientation(QtCore.Qt.Vertical)
        self.splitter_5.setObjectName("splitter_5")
        self.mp_2t_map = MplCanvasBarH(self.splitter_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mp_2t_map.sizePolicy().hasHeightForWidth())
        self.mp_2t_map.setSizePolicy(sizePolicy)
        self.mp_2t_map.setMinimumSize(QtCore.QSize(300, 200))
        self.mp_2t_map.setObjectName("mp_2t_map")
        self.mp_2t = MplCanvasBarH(self.splitter_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mp_2t.sizePolicy().hasHeightForWidth())
        self.mp_2t.setSizePolicy(sizePolicy)
        self.mp_2t.setMinimumSize(QtCore.QSize(300, 200))
        self.mp_2t.setObjectName("mp_2t")
        self.gridLayout_33.addWidget(self.splitter_5, 0, 0, 1, 1)
        self.groupBox_11 = QtWidgets.QGroupBox(self.tab_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_11.sizePolicy().hasHeightForWidth())
        self.groupBox_11.setSizePolicy(sizePolicy)
        self.groupBox_11.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_11.setMaximumSize(QtCore.QSize(16777215, 65536))
        self.groupBox_11.setObjectName("groupBox_11")
        self.gridLayout_37 = QtWidgets.QGridLayout(self.groupBox_11)
        self.gridLayout_37.setObjectName("gridLayout_37")
        spacerItem8 = QtWidgets.QSpacerItem(279, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_37.addItem(spacerItem8, 0, 0, 1, 1)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.cb_twotime_saxs_cmap = QtWidgets.QComboBox(self.groupBox_11)
        self.cb_twotime_saxs_cmap.setObjectName("cb_twotime_saxs_cmap")
        self.cb_twotime_saxs_cmap.addItem("")
        self.cb_twotime_saxs_cmap.addItem("")
        self.cb_twotime_saxs_cmap.addItem("")
        self.cb_twotime_saxs_cmap.addItem("")
        self.cb_twotime_saxs_cmap.addItem("")
        self.cb_twotime_saxs_cmap.addItem("")
        self.gridLayout_2.addWidget(self.cb_twotime_saxs_cmap, 0, 5, 1, 2)
        self.cb_twotime_cmap = QtWidgets.QComboBox(self.groupBox_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cb_twotime_cmap.sizePolicy().hasHeightForWidth())
        self.cb_twotime_cmap.setSizePolicy(sizePolicy)
        self.cb_twotime_cmap.setMinimumSize(QtCore.QSize(0, 0))
        self.cb_twotime_cmap.setObjectName("cb_twotime_cmap")
        self.cb_twotime_cmap.addItem("")
        self.cb_twotime_cmap.addItem("")
        self.cb_twotime_cmap.addItem("")
        self.cb_twotime_cmap.addItem("")
        self.cb_twotime_cmap.addItem("")
        self.cb_twotime_cmap.addItem("")
        self.gridLayout_2.addWidget(self.cb_twotime_cmap, 1, 9, 1, 1)
        self.label_36 = QtWidgets.QLabel(self.groupBox_11)
        self.label_36.setObjectName("label_36")
        self.gridLayout_2.addWidget(self.label_36, 0, 0, 1, 1)
        self.label_29 = QtWidgets.QLabel(self.groupBox_11)
        self.label_29.setObjectName("label_29")
        self.gridLayout_2.addWidget(self.label_29, 1, 0, 1, 1)
        self.twotime_autocrop = QtWidgets.QCheckBox(self.groupBox_11)
        self.twotime_autocrop.setChecked(True)
        self.twotime_autocrop.setObjectName("twotime_autocrop")
        self.gridLayout_2.addWidget(self.twotime_autocrop, 0, 11, 1, 1)
        self.cb_twotime_qmap_cmap = QtWidgets.QComboBox(self.groupBox_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cb_twotime_qmap_cmap.sizePolicy().hasHeightForWidth())
        self.cb_twotime_qmap_cmap.setSizePolicy(sizePolicy)
        self.cb_twotime_qmap_cmap.setMinimumSize(QtCore.QSize(0, 0))
        self.cb_twotime_qmap_cmap.setObjectName("cb_twotime_qmap_cmap")
        self.cb_twotime_qmap_cmap.addItem("")
        self.cb_twotime_qmap_cmap.addItem("")
        self.cb_twotime_qmap_cmap.addItem("")
        self.cb_twotime_qmap_cmap.addItem("")
        self.cb_twotime_qmap_cmap.addItem("")
        self.cb_twotime_qmap_cmap.addItem("")
        self.gridLayout_2.addWidget(self.cb_twotime_qmap_cmap, 0, 9, 1, 1)
        self.twotime_autorotate = QtWidgets.QCheckBox(self.groupBox_11)
        self.twotime_autorotate.setChecked(True)
        self.twotime_autorotate.setObjectName("twotime_autorotate")
        self.gridLayout_2.addWidget(self.twotime_autorotate, 0, 10, 1, 1)
        self.cb_twotime_type = QtWidgets.QComboBox(self.groupBox_11)
        self.cb_twotime_type.setObjectName("cb_twotime_type")
        self.cb_twotime_type.addItem("")
        self.cb_twotime_type.addItem("")
        self.gridLayout_2.addWidget(self.cb_twotime_type, 0, 1, 1, 2)
        self.label_35 = QtWidgets.QLabel(self.groupBox_11)
        self.label_35.setObjectName("label_35")
        self.gridLayout_2.addWidget(self.label_35, 0, 3, 1, 2)
        self.label_37 = QtWidgets.QLabel(self.groupBox_11)
        self.label_37.setObjectName("label_37")
        self.gridLayout_2.addWidget(self.label_37, 0, 7, 1, 2)
        self.pushButton_12 = QtWidgets.QPushButton(self.groupBox_11)
        self.pushButton_12.setObjectName("pushButton_12")
        self.gridLayout_2.addWidget(self.pushButton_12, 1, 10, 1, 2)
        self.label_27 = QtWidgets.QLabel(self.groupBox_11)
        self.label_27.setObjectName("label_27")
        self.gridLayout_2.addWidget(self.label_27, 1, 3, 1, 2)
        self.label_28 = QtWidgets.QLabel(self.groupBox_11)
        self.label_28.setObjectName("label_28")
        self.gridLayout_2.addWidget(self.label_28, 1, 7, 1, 2)
        self.twotime_q_index = QtWidgets.QSpinBox(self.groupBox_11)
        self.twotime_q_index.setMinimum(0)
        self.twotime_q_index.setMaximum(9999)
        self.twotime_q_index.setProperty("value", 3)
        self.twotime_q_index.setObjectName("twotime_q_index")
        self.gridLayout_2.addWidget(self.twotime_q_index, 1, 5, 1, 2)
        self.cb_twotime_group = QtWidgets.QComboBox(self.groupBox_11)
        self.cb_twotime_group.setObjectName("cb_twotime_group")
        self.gridLayout_2.addWidget(self.cb_twotime_group, 1, 1, 1, 2)
        self.gridLayout_37.addLayout(self.gridLayout_2, 0, 1, 1, 1)
        spacerItem9 = QtWidgets.QSpacerItem(278, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_37.addItem(spacerItem9, 0, 2, 1, 1)
        self.gridLayout_33.addWidget(self.groupBox_11, 1, 0, 1, 1)
        self.tabWidget.addTab(self.tab_8, "")
        self.tab_9 = QtWidgets.QWidget()
        self.tab_9.setObjectName("tab_9")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.tab_9)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.hdf_info = QtWidgets.QTextBrowser(self.tab_9)
        font = QtGui.QFont()
        font.setFamily("Menlo")
        self.hdf_info.setFont(font)
        self.hdf_info.setObjectName("hdf_info")
        self.gridLayout_7.addWidget(self.hdf_info, 0, 0, 1, 1)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem10)
        self.hdf_list = QtWidgets.QComboBox(self.tab_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.hdf_list.sizePolicy().hasHeightForWidth())
        self.hdf_list.setSizePolicy(sizePolicy)
        self.hdf_list.setMinimumSize(QtCore.QSize(450, 0))
        self.hdf_list.setObjectName("hdf_list")
        self.horizontalLayout_5.addWidget(self.hdf_list)
        self.hdf_key_filter = QtWidgets.QLineEdit(self.tab_9)
        self.hdf_key_filter.setMinimumSize(QtCore.QSize(360, 0))
        self.hdf_key_filter.setClearButtonEnabled(True)
        self.hdf_key_filter.setObjectName("hdf_key_filter")
        self.horizontalLayout_5.addWidget(self.hdf_key_filter)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem11)
        self.gridLayout_7.addLayout(self.horizontalLayout_5, 1, 0, 1, 1)
        self.tabWidget.addTab(self.tab_9, "")
        self.tab_10 = QtWidgets.QWidget()
        self.tab_10.setObjectName("tab_10")
        self.gridLayout_34 = QtWidgets.QGridLayout(self.tab_10)
        self.gridLayout_34.setObjectName("gridLayout_34")
        self.console_panel = QtWidgets.QWidget(self.tab_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.console_panel.sizePolicy().hasHeightForWidth())
        self.console_panel.setSizePolicy(sizePolicy)
        self.console_panel.setObjectName("console_panel")
        self.gridLayout_34.addWidget(self.console_panel, 0, 0, 1, 1)
        self.tabWidget.addTab(self.tab_10, "")
        self.gridLayout_32.addWidget(self.splitter_4, 0, 0, 1, 1)
        self.gridLayout.addWidget(self.file_panel, 0, 0, 1, 1)
        mainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(mainWindow)
        self.statusbar.setObjectName("statusbar")
        mainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(mainWindow)
        self.tabWidget.setCurrentIndex(0)
        self.cb_saxs_type.setCurrentIndex(3)
        self.cb_stab_type.setCurrentIndex(3)
        self.cb_stab_norm.setCurrentIndex(0)
        self.cb_avg_chunk_size.setCurrentIndex(2)
        self.cb_tauq_type.setCurrentIndex(3)
        self.twotime_q_index.valueChanged['int'].connect(mainWindow.plot_twotime)
        self.pushButton_4.clicked.connect(mainWindow.plot_g2)
        self.pushButton_13.clicked.connect(mainWindow.edit_label)
        self.hdf_list.currentIndexChanged['int'].connect(mainWindow.show_hdf_info)
        self.filter_str.textChanged['QString'].connect(mainWindow.trie_search)
        self.sb_window.valueChanged['int'].connect(self.btn_intt.click)
        self.sb_intt_sampling.valueChanged['int'].connect(self.btn_intt.click)
        self.sb_stab_offset.valueChanged['double'].connect(self.pushButton_7.click)
        self.pushButton_3.clicked.connect(mainWindow.remove_target)
        self.g2_qmax.editingFinished.connect(mainWindow.check_g2_number)
        self.cb_stab.currentIndexChanged['int'].connect(self.pushButton_7.click)
        self.cb_saxs2D_type.currentIndexChanged['int'].connect(self.pushButton_5.click)
        self.pushButton_8.clicked.connect(mainWindow.plot_tauq)
        self.g2_ymin.editingFinished.connect(mainWindow.check_g2_number)
        self.cb_stab_type.currentIndexChanged['int'].connect(self.pushButton_7.click)
        self.sb_saxs_offset.valueChanged['double'].connect(self.pushButton_10.click)
        self.g2_tmax.editingFinished.connect(mainWindow.check_g2_number)
        self.pushButton.clicked.connect(mainWindow.load_path)
        self.g2_qmin.editingFinished.connect(mainWindow.check_g2_number)
        self.cb_saxs2D_cmap.currentIndexChanged['int'].connect(self.pushButton_5.click)
        self.pushButton_2.clicked.connect(mainWindow.add_target)
        self.cb_saxs_norm.currentIndexChanged['int'].connect(self.pushButton_10.click)
        self.pushButton_7.clicked.connect(mainWindow.plot_stability_iq)
        self.g2_ymax.editingFinished.connect(mainWindow.check_g2_number)
        self.saxs2d_autorotate.stateChanged['int'].connect(self.pushButton_5.click)
        self.intt_xlabel.currentIndexChanged['int'].connect(self.btn_intt.click)
        self.pushButton_11.clicked.connect(mainWindow.reload_source)
        self.cb_saxs_type.currentIndexChanged['int'].connect(self.pushButton_10.click)
        self.cb_stab_norm.currentIndexChanged['int'].connect(self.pushButton_7.click)
        self.pushButton_12.clicked['bool'].connect(mainWindow.plot_twotime)
        self.g2_tmin.editingFinished.connect(mainWindow.check_g2_number)
        self.pushButton_5.clicked.connect(mainWindow.plot_saxs_2D)
        self.box_auto_update.stateChanged['int'].connect(mainWindow.load_data)
        self.pushButton_10.clicked.connect(mainWindow.plot_saxs_1D)
        self.btn_load_data.clicked.connect(mainWindow.load_data)
        self.btn_intt.clicked.connect(mainWindow.plot_intt)
        self.hdf_key_filter.returnPressed.connect(mainWindow.show_hdf_info)
        self.sb_intt_max.valueChanged['int'].connect(self.btn_intt.click)
        self.cb_twotime_cmap.currentIndexChanged['int'].connect(mainWindow.plot_twotime)
        self.filter_str.returnPressed.connect(self.pushButton_2.click)
        self.sb_g2_column.editingFinished.connect(self.pushButton_4.click)
        self.sb_g2_offset.editingFinished.connect(self.pushButton_4.click)
        self.g2_show_label.stateChanged['int'].connect(self.pushButton_4.click)
        self.g2_show_fit.stateChanged['int'].connect(self.pushButton_4.click)
        self.g2_plot_type.currentIndexChanged['int'].connect(self.pushButton_4.click)
        self.g2_qmin.editingFinished.connect(self.pushButton_4.click)
        self.g2_qmax.editingFinished.connect(self.pushButton_4.click)
        self.g2_tmin.editingFinished.connect(self.pushButton_4.click)
        self.g2_tmax.editingFinished.connect(self.pushButton_4.click)
        self.g2_ymin.editingFinished.connect(self.pushButton_4.click)
        self.g2_ymax.editingFinished.connect(self.pushButton_4.click)
        self.g2_afit.toggled['bool'].connect(self.g2_amin.setEnabled)
        self.g2_bfit.toggled['bool'].connect(self.g2_bmin.setEnabled)
        self.g2_cfit.toggled['bool'].connect(self.g2_cmin.setEnabled)
        self.g2_dfit.toggled['bool'].connect(self.g2_dmin.setEnabled)
        self.tauq_afit.toggled['bool'].connect(self.tauq_amin.setEnabled)
        self.tauq_bfit.toggled['bool'].connect(self.tauq_bmin.setEnabled)
        self.cb_tauq_type.currentIndexChanged['int'].connect(self.pushButton_8.click)
        self.sb_tauq_offset.editingFinished.connect(self.pushButton_8.click)
        self.saxs1d_qmin.valueChanged['double'].connect(self.pushButton_10.click)
        self.saxs1d_qmax.valueChanged['double'].connect(self.pushButton_10.click)
        self.g2_show_fit.toggled['bool'].connect(self.g2_sub_baseline.setEnabled)
        self.g2_sub_baseline.stateChanged['int'].connect(self.pushButton_4.click)
        self.g2_yauto.toggled['bool'].connect(self.g2_ymin.setDisabled)
        self.g2_yauto.toggled['bool'].connect(self.g2_ymax.setDisabled)
        QtCore.QMetaObject.connectSlotsByName(mainWindow)
        mainWindow.setTabOrder(self.work_dir, self.pushButton)
        mainWindow.setTabOrder(self.pushButton, self.pushButton_11)
        mainWindow.setTabOrder(self.pushButton_11, self.list_view_source)
        mainWindow.setTabOrder(self.list_view_source, self.filter_type)
        mainWindow.setTabOrder(self.filter_type, self.filter_str)
        mainWindow.setTabOrder(self.filter_str, self.pushButton_2)
        mainWindow.setTabOrder(self.pushButton_2, self.pushButton_3)
        mainWindow.setTabOrder(self.pushButton_3, self.box_auto_update)
        mainWindow.setTabOrder(self.box_auto_update, self.btn_load_data)
        mainWindow.setTabOrder(self.btn_load_data, self.pushButton_13)
        mainWindow.setTabOrder(self.pushButton_13, self.list_view_target)
        mainWindow.setTabOrder(self.list_view_target, self.tabWidget)
        mainWindow.setTabOrder(self.tabWidget, self.saxs2d_display)
        mainWindow.setTabOrder(self.saxs2d_display, self.cb_saxs2D_cmap)
        mainWindow.setTabOrder(self.cb_saxs2D_cmap, self.cb_saxs2D_type)
        mainWindow.setTabOrder(self.cb_saxs2D_type, self.pushButton_5)
        mainWindow.setTabOrder(self.pushButton_5, self.cb_saxs_type)
        mainWindow.setTabOrder(self.cb_saxs_type, self.sb_saxs_offset)
        mainWindow.setTabOrder(self.sb_saxs_offset, self.pushButton_10)
        mainWindow.setTabOrder(self.pushButton_10, self.cb_stab_type)
        mainWindow.setTabOrder(self.cb_stab_type, self.sb_stab_offset)
        mainWindow.setTabOrder(self.sb_stab_offset, self.pushButton_7)
        mainWindow.setTabOrder(self.pushButton_7, self.cb_stab)
        mainWindow.setTabOrder(self.cb_stab, self.cb_stab_norm)
        mainWindow.setTabOrder(self.cb_stab_norm, self.sb_intt_max)
        mainWindow.setTabOrder(self.sb_intt_max, self.sb_window)
        mainWindow.setTabOrder(self.sb_window, self.sb_intt_sampling)
        mainWindow.setTabOrder(self.sb_intt_sampling, self.intt_xlabel)
        mainWindow.setTabOrder(self.intt_xlabel, self.btn_intt)
        mainWindow.setTabOrder(self.btn_intt, self.max_thread_count)
        mainWindow.setTabOrder(self.max_thread_count, self.avg_blmax)
        mainWindow.setTabOrder(self.avg_blmax, self.avg_blmin)
        mainWindow.setTabOrder(self.avg_blmin, self.avg_save_path)
        mainWindow.setTabOrder(self.avg_save_path, self.cb_avg_chunk_size)
        mainWindow.setTabOrder(self.cb_avg_chunk_size, self.btn_set_average_save_name)
        mainWindow.setTabOrder(self.btn_set_average_save_name, self.bx_avg_G2IPIF)
        mainWindow.setTabOrder(self.bx_avg_G2IPIF, self.avg_window)
        mainWindow.setTabOrder(self.avg_window, self.bx_avg_g2g2err)
        mainWindow.setTabOrder(self.bx_avg_g2g2err, self.avg_save_name)
        mainWindow.setTabOrder(self.avg_save_name, self.btn_set_average_save_path)
        mainWindow.setTabOrder(self.btn_set_average_save_path, self.bx_avg_saxs)
        mainWindow.setTabOrder(self.bx_avg_saxs, self.avg_qindex)
        mainWindow.setTabOrder(self.avg_qindex, self.btn_submit_job)
        mainWindow.setTabOrder(self.btn_submit_job, self.avg_job_pop)
        mainWindow.setTabOrder(self.avg_job_pop, self.btn_avg_jobinfo)
        mainWindow.setTabOrder(self.btn_avg_jobinfo, self.btn_avg_kill)
        mainWindow.setTabOrder(self.btn_avg_kill, self.btn_start_avg_job)
        mainWindow.setTabOrder(self.btn_start_avg_job, self.avg_job_table)
        mainWindow.setTabOrder(self.avg_job_table, self.scrollArea)
        mainWindow.setTabOrder(self.scrollArea, self.g2_show_label)
        mainWindow.setTabOrder(self.g2_show_label, self.pushButton_4)
        mainWindow.setTabOrder(self.pushButton_4, self.sb_g2_column)
        mainWindow.setTabOrder(self.sb_g2_column, self.g2_ymin)
        mainWindow.setTabOrder(self.g2_ymin, self.g2_ymax)
        mainWindow.setTabOrder(self.g2_ymax, self.sb_g2_offset)
        mainWindow.setTabOrder(self.sb_g2_offset, self.g2_qmax)
        mainWindow.setTabOrder(self.g2_qmax, self.g2_show_fit)
        mainWindow.setTabOrder(self.g2_show_fit, self.g2_qmin)
        mainWindow.setTabOrder(self.g2_qmin, self.g2_tmin)
        mainWindow.setTabOrder(self.g2_tmin, self.g2_tmax)
        mainWindow.setTabOrder(self.g2_tmax, self.g2_plot_type)
        mainWindow.setTabOrder(self.g2_plot_type, self.g2_amin)
        mainWindow.setTabOrder(self.g2_amin, self.g2_amax)
        mainWindow.setTabOrder(self.g2_amax, self.g2_afit)
        mainWindow.setTabOrder(self.g2_afit, self.g2_bmin)
        mainWindow.setTabOrder(self.g2_bmin, self.g2_bmax)
        mainWindow.setTabOrder(self.g2_bmax, self.g2_bfit)
        mainWindow.setTabOrder(self.g2_bfit, self.g2_cmin)
        mainWindow.setTabOrder(self.g2_cmin, self.g2_cmax)
        mainWindow.setTabOrder(self.g2_cmax, self.g2_cfit)
        mainWindow.setTabOrder(self.g2_cfit, self.g2_dmin)
        mainWindow.setTabOrder(self.g2_dmin, self.g2_dmax)
        mainWindow.setTabOrder(self.g2_dmax, self.g2_dfit)
        mainWindow.setTabOrder(self.g2_dfit, self.show_g2_fit_summary)
        mainWindow.setTabOrder(self.show_g2_fit_summary, self.btn_g2_refit)
        mainWindow.setTabOrder(self.btn_g2_refit, self.twotime_autorotate)
        mainWindow.setTabOrder(self.twotime_autorotate, self.cb_twotime_type)
        mainWindow.setTabOrder(self.cb_twotime_type, self.cb_twotime_qmap_cmap)
        mainWindow.setTabOrder(self.cb_twotime_qmap_cmap, self.twotime_autocrop)
        mainWindow.setTabOrder(self.twotime_autocrop, self.cb_twotime_saxs_cmap)
        mainWindow.setTabOrder(self.cb_twotime_saxs_cmap, self.cb_twotime_cmap)
        mainWindow.setTabOrder(self.cb_twotime_cmap, self.tauq_amin)
        mainWindow.setTabOrder(self.tauq_amin, self.tauq_amax)
        mainWindow.setTabOrder(self.tauq_amax, self.tauq_afit)
        mainWindow.setTabOrder(self.tauq_afit, self.tauq_bmin)
        mainWindow.setTabOrder(self.tauq_bmin, self.tauq_bmax)
        mainWindow.setTabOrder(self.tauq_bmax, self.tauq_bfit)
        mainWindow.setTabOrder(self.tauq_bfit, self.tauq_qmin)
        mainWindow.setTabOrder(self.tauq_qmin, self.tauq_qmax)
        mainWindow.setTabOrder(self.tauq_qmax, self.pushButton_8)
        mainWindow.setTabOrder(self.pushButton_8, self.cb_tauq_type)
        mainWindow.setTabOrder(self.cb_tauq_type, self.sb_tauq_offset)
        mainWindow.setTabOrder(self.sb_tauq_offset, self.pushButton_12)
        mainWindow.setTabOrder(self.pushButton_12, self.twotime_q_index)
        mainWindow.setTabOrder(self.twotime_q_index, self.cb_twotime_group)
        mainWindow.setTabOrder(self.cb_twotime_group, self.hdf_info)
        mainWindow.setTabOrder(self.hdf_info, self.hdf_list)
        mainWindow.setTabOrder(self.hdf_list, self.hdf_key_filter)

    def retranslateUi(self, mainWindow):
        _translate = QtCore.QCoreApplication.translate
        mainWindow.setWindowTitle(_translate("mainWindow", "XPCS_Viewer"))
        self.label_2.setText(_translate("mainWindow", "Path:"))
        self.pushButton.setText(_translate("mainWindow", "browse"))
        self.pushButton_11.setText(_translate("mainWindow", "reload"))
        self.box_source.setTitle(_translate("mainWindow", "Source:"))
        self.filter_type.setItemText(0, _translate("mainWindow", "prefix is"))
        self.filter_type.setItemText(1, _translate("mainWindow", "contains"))
        self.filter_str.setPlaceholderText(_translate("mainWindow", "filter, press enter to add files"))
        self.pushButton_2.setText(_translate("mainWindow", "add"))
        self.pushButton_3.setText(_translate("mainWindow", "remove"))
        self.box_target.setTitle(_translate("mainWindow", "Target:"))
        self.label_30.setText(_translate("mainWindow", "progress:"))
        self.box_auto_update.setText(_translate("mainWindow", "auto"))
        self.btn_load_data.setText(_translate("mainWindow", "update"))
        self.pushButton_13.setText(_translate("mainWindow", "view"))
        self.label_38.setText(_translate("mainWindow", "coordinates:"))
        self.groupBox_3.setTitle(_translate("mainWindow", "SAXS 2D Plot Setting"))
        self.label_13.setText(_translate("mainWindow", "colormap:"))
        self.label_12.setText(_translate("mainWindow", "type:"))
        self.cb_saxs2D_type.setItemText(0, _translate("mainWindow", "log"))
        self.cb_saxs2D_type.setItemText(1, _translate("mainWindow", "linear"))
        self.cb_saxs2D_cmap.setItemText(0, _translate("mainWindow", "jet"))
        self.cb_saxs2D_cmap.setItemText(1, _translate("mainWindow", "hot"))
        self.cb_saxs2D_cmap.setItemText(2, _translate("mainWindow", "plasma"))
        self.cb_saxs2D_cmap.setItemText(3, _translate("mainWindow", "viridis"))
        self.cb_saxs2D_cmap.setItemText(4, _translate("mainWindow", "magma"))
        self.cb_saxs2D_cmap.setItemText(5, _translate("mainWindow", "gray"))
        self.pushButton_5.setText(_translate("mainWindow", "Plot 2D SAXS"))
        self.label_50.setText(_translate("mainWindow", "min:"))
        self.label_51.setText(_translate("mainWindow", "max:"))
        self.saxs2d_autorange.setText(_translate("mainWindow", "auto-range"))
        self.saxs2d_autorotate.setText(_translate("mainWindow", "auto-rotate"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab1_1), _translate("mainWindow", "SAXS-2D"))
        self.groupBox_6.setTitle(_translate("mainWindow", "SAXS 1D Plot Setting"))
        self.label_23.setText(_translate("mainWindow", "normalization:"))
        self.pushButton_10.setText(_translate("mainWindow", "Plot 1D SAXS"))
        self.label_22.setText(_translate("mainWindow", "offset:"))
        self.cb_saxs_type.setItemText(0, _translate("mainWindow", "I - q"))
        self.cb_saxs_type.setItemText(1, _translate("mainWindow", "I - log(q)"))
        self.cb_saxs_type.setItemText(2, _translate("mainWindow", "log(I) - q"))
        self.cb_saxs_type.setItemText(3, _translate("mainWindow", "log(I) - log(q)"))
        self.label_21.setText(_translate("mainWindow", "type:"))
        self.label_49.setText(_translate("mainWindow", "q range (Å⁻¹)"))
        self.cb_saxs_norm.setItemText(0, _translate("mainWindow", "none"))
        self.cb_saxs_norm.setItemText(1, _translate("mainWindow", "I\' = Iq2"))
        self.cb_saxs_norm.setItemText(2, _translate("mainWindow", "I\' = Iq4"))
        self.cb_saxs_norm.setItemText(3, _translate("mainWindow", "I\' = I/Io"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("mainWindow", "SAXS-1D"))
        self.groupBox_4.setTitle(_translate("mainWindow", "Stability Plot Setting"))
        self.label_14.setText(_translate("mainWindow", "type:"))
        self.cb_stab_type.setItemText(0, _translate("mainWindow", "I - q"))
        self.cb_stab_type.setItemText(1, _translate("mainWindow", "I - log(q)"))
        self.cb_stab_type.setItemText(2, _translate("mainWindow", "log(I) - q"))
        self.cb_stab_type.setItemText(3, _translate("mainWindow", "log(I) - log(q)"))
        self.label_24.setText(_translate("mainWindow", "offset:"))
        self.label_16.setText(_translate("mainWindow", "normalization:"))
        self.pushButton_7.setText(_translate("mainWindow", "Plot Iq Stability Data"))
        self.cb_stab_norm.setItemText(0, _translate("mainWindow", "none"))
        self.cb_stab_norm.setItemText(1, _translate("mainWindow", "I\' = Iq2"))
        self.cb_stab_norm.setItemText(2, _translate("mainWindow", "I\' = Iq4"))
        self.cb_stab_norm.setItemText(3, _translate("mainWindow", "I\' = I/Io"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("mainWindow", "Stability"))
        self.groupBox_7.setTitle(_translate("mainWindow", "Setting"))
        self.label_9.setText(_translate("mainWindow", "max datasets:"))
        self.label_34.setText(_translate("mainWindow", "xlabel:"))
        self.label_31.setText(_translate("mainWindow", "moving average:"))
        self.label_11.setText(_translate("mainWindow", "sampling:"))
        self.intt_xlabel.setItemText(0, _translate("mainWindow", "Time (second)"))
        self.intt_xlabel.setItemText(1, _translate("mainWindow", "Frame Index"))
        self.btn_intt.setText(_translate("mainWindow", "plot Intensity-T"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), _translate("mainWindow", "Intensity-Time"))
        self.groupBox_10.setTitle(_translate("mainWindow", "g2 outlier"))
        self.groupBox_8.setTitle(_translate("mainWindow", "Averaging setting:"))
        self.label_39.setText(_translate("mainWindow", "g2 max:"))
        self.cb_avg_chunk_size.setItemText(0, _translate("mainWindow", "32"))
        self.cb_avg_chunk_size.setItemText(1, _translate("mainWindow", "64"))
        self.cb_avg_chunk_size.setItemText(2, _translate("mainWindow", "128"))
        self.cb_avg_chunk_size.setItemText(3, _translate("mainWindow", "256"))
        self.cb_avg_chunk_size.setItemText(4, _translate("mainWindow", "512"))
        self.btn_set_average_save_name.setText(_translate("mainWindow", "..."))
        self.label_17.setText(_translate("mainWindow", "batch size:"))
        self.label_32.setText(_translate("mainWindow", "q_index:"))
        self.label_25.setText(_translate("mainWindow", "g2 min:"))
        self.label_19.setText(_translate("mainWindow", "save name:"))
        self.bx_avg_G2IPIF.setText(_translate("mainWindow", "G2/IP/IF"))
        self.bx_avg_g2g2err.setText(_translate("mainWindow", "g2/g2err"))
        self.label_20.setText(_translate("mainWindow", "save path:"))
        self.btn_set_average_save_path.setText(_translate("mainWindow", "..."))
        self.bx_avg_saxs.setText(_translate("mainWindow", "saxs 1d/2d"))
        self.label_26.setText(_translate("mainWindow", "selection:"))
        self.label_33.setText(_translate("mainWindow", "avg_window:"))
        self.label_40.setText(_translate("mainWindow", "max_thread:"))
        self.groupBox_12.setTitle(_translate("mainWindow", "Action:"))
        self.btn_submit_job.setText(_translate("mainWindow", "submit"))
        self.avg_job_pop.setText(_translate("mainWindow", "delete"))
        self.btn_avg_jobinfo.setText(_translate("mainWindow", "info"))
        self.btn_avg_kill.setText(_translate("mainWindow", "kill"))
        self.btn_start_avg_job.setText(_translate("mainWindow", "start"))
        self.groupBox_9.setTitle(_translate("mainWindow", "Averaging Job List"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), _translate("mainWindow", "Average"))
        self.groupBox.setTitle(_translate("mainWindow", "Data Selection:"))
        self.label_4.setText(_translate("mainWindow", "t range:"))
        self.label_3.setText(_translate("mainWindow", "q (1/Å):"))
        self.g2_ymin.setText(_translate("mainWindow", "0.98"))
        self.g2_ymin.setPlaceholderText(_translate("mainWindow", "min"))
        self.g2_qmin.setText(_translate("mainWindow", "0"))
        self.g2_qmin.setPlaceholderText(_translate("mainWindow", "min"))
        self.label_7.setText(_translate("mainWindow", "y range"))
        self.g2_tmin.setText(_translate("mainWindow", "2E-6"))
        self.g2_tmin.setPlaceholderText(_translate("mainWindow", "min"))
        self.g2_qmax.setText(_translate("mainWindow", "0.0092"))
        self.g2_qmax.setPlaceholderText(_translate("mainWindow", "max"))
        self.g2_tmax.setText(_translate("mainWindow", "0.5"))
        self.g2_tmax.setPlaceholderText(_translate("mainWindow", "max"))
        self.g2_ymax.setText(_translate("mainWindow", "1.20"))
        self.g2_ymax.setPlaceholderText(_translate("mainWindow", "max"))
        self.g2_yauto.setText(_translate("mainWindow", "auto"))
        self.label_8.setText(_translate("mainWindow", "column:"))
        self.label.setText(_translate("mainWindow", "offset:"))
        self.g2_show_fit.setText(_translate("mainWindow", "do fit?"))
        self.pushButton_4.setText(_translate("mainWindow", "plot"))
        self.g2_sub_baseline.setText(_translate("mainWindow", "subtract baseline"))
        self.g2_show_label.setText(_translate("mainWindow", "show labels?"))
        self.g2_plot_type.setItemText(0, _translate("mainWindow", "multiple"))
        self.g2_plot_type.setItemText(1, _translate("mainWindow", "single"))
        self.g2_plot_type.setItemText(2, _translate("mainWindow", "single-combined"))
        self.groupBox_2.setTitle(_translate("mainWindow", "Single Exponential Fitting: y = a·exp[-2(x/b)^c]+d"))
        self.show_g2_fit_summary.setText(_translate("mainWindow", "show_values"))
        self.btn_g2_refit.setText(_translate("mainWindow", "refit"))
        self.label_45.setText(_translate("mainWindow", "contrast:"))
        self.label_5.setText(_translate("mainWindow", "a"))
        self.g2_amin.setText(_translate("mainWindow", "0.08"))
        self.g2_amin.setPlaceholderText(_translate("mainWindow", "min"))
        self.g2_amax.setText(_translate("mainWindow", "0.20"))
        self.g2_amax.setPlaceholderText(_translate("mainWindow", "max"))
        self.g2_afit.setText(_translate("mainWindow", "fit"))
        self.label_46.setText(_translate("mainWindow", "tau (s):"))
        self.label_6.setText(_translate("mainWindow", "b"))
        self.g2_bmin.setText(_translate("mainWindow", "1e-6"))
        self.g2_bmin.setPlaceholderText(_translate("mainWindow", "min"))
        self.g2_bmax.setText(_translate("mainWindow", "1e1"))
        self.g2_bmax.setPlaceholderText(_translate("mainWindow", "max"))
        self.g2_bfit.setText(_translate("mainWindow", "fit"))
        self.label_47.setText(_translate("mainWindow", "stretch:"))
        self.label_10.setText(_translate("mainWindow", "c"))
        self.g2_cmin.setText(_translate("mainWindow", "0.50"))
        self.g2_cmin.setPlaceholderText(_translate("mainWindow", "min"))
        self.g2_cmax.setText(_translate("mainWindow", "2.00"))
        self.g2_cmax.setPlaceholderText(_translate("mainWindow", "max"))
        self.g2_cfit.setText(_translate("mainWindow", "fit"))
        self.label_48.setText(_translate("mainWindow", "baseline:"))
        self.label_41.setText(_translate("mainWindow", "d"))
        self.g2_dmin.setText(_translate("mainWindow", "0.95"))
        self.g2_dmin.setPlaceholderText(_translate("mainWindow", "min"))
        self.g2_dmax.setText(_translate("mainWindow", "1.05"))
        self.g2_dmax.setPlaceholderText(_translate("mainWindow", "max"))
        self.g2_dfit.setText(_translate("mainWindow", "fit"))
        self.btn_g2_export.setText(_translate("mainWindow", "export figure"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_6), _translate("mainWindow", "g2"))
        self.groupBox_5.setTitle(_translate("mainWindow", "Power Law Fitting: y = a·x^b"))
        self.label_15.setText(_translate("mainWindow", "plot_type:"))
        self.cb_tauq_type.setItemText(0, _translate("mainWindow", "t-q"))
        self.cb_tauq_type.setItemText(1, _translate("mainWindow", "τ-log(q)"))
        self.cb_tauq_type.setItemText(2, _translate("mainWindow", "log(τ)-q"))
        self.cb_tauq_type.setItemText(3, _translate("mainWindow", "log(τ)-log(q)"))
        self.label_18.setText(_translate("mainWindow", "Offset:"))
        self.tauq_amax.setText(_translate("mainWindow", "1.00e-3"))
        self.tauq_amax.setPlaceholderText(_translate("mainWindow", "max"))
        self.tauq_qmax.setText(_translate("mainWindow", "0.0092"))
        self.tauq_qmax.setPlaceholderText(_translate("mainWindow", "max"))
        self.tauq_bfit.setText(_translate("mainWindow", "fit"))
        self.label_44.setText(_translate("mainWindow", "a"))
        self.tauq_bmin.setText(_translate("mainWindow", "-2.5"))
        self.tauq_bmin.setPlaceholderText(_translate("mainWindow", "min"))
        self.label_42.setText(_translate("mainWindow", "b"))
        self.tauq_amin.setText(_translate("mainWindow", "1.00e-12"))
        self.tauq_amin.setPlaceholderText(_translate("mainWindow", "min"))
        self.tauq_afit.setText(_translate("mainWindow", "fit"))
        self.tauq_bmax.setText(_translate("mainWindow", "-0.5"))
        self.tauq_bmax.setPlaceholderText(_translate("mainWindow", "max"))
        self.tauq_qmin.setText(_translate("mainWindow", "0.001"))
        self.tauq_qmin.setPlaceholderText(_translate("mainWindow", "min"))
        self.label_43.setText(_translate("mainWindow", "q (Å⁻¹)"))
        self.pushButton_8.setText(_translate("mainWindow", "fit plot"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_7), _translate("mainWindow", "Diffusion"))
        self.groupBox_11.setTitle(_translate("mainWindow", "Twotime Setting"))
        self.cb_twotime_saxs_cmap.setItemText(0, _translate("mainWindow", "jet"))
        self.cb_twotime_saxs_cmap.setItemText(1, _translate("mainWindow", "hot"))
        self.cb_twotime_saxs_cmap.setItemText(2, _translate("mainWindow", "plasma"))
        self.cb_twotime_saxs_cmap.setItemText(3, _translate("mainWindow", "viridis"))
        self.cb_twotime_saxs_cmap.setItemText(4, _translate("mainWindow", "magma"))
        self.cb_twotime_saxs_cmap.setItemText(5, _translate("mainWindow", "gray"))
        self.cb_twotime_cmap.setItemText(0, _translate("mainWindow", "jet"))
        self.cb_twotime_cmap.setItemText(1, _translate("mainWindow", "hot"))
        self.cb_twotime_cmap.setItemText(2, _translate("mainWindow", "plasma"))
        self.cb_twotime_cmap.setItemText(3, _translate("mainWindow", "viridis"))
        self.cb_twotime_cmap.setItemText(4, _translate("mainWindow", "magma"))
        self.cb_twotime_cmap.setItemText(5, _translate("mainWindow", "gray"))
        self.label_36.setText(_translate("mainWindow", "type:"))
        self.label_29.setText(_translate("mainWindow", "Group:"))
        self.twotime_autocrop.setText(_translate("mainWindow", "auto-crop?"))
        self.cb_twotime_qmap_cmap.setItemText(0, _translate("mainWindow", "gray"))
        self.cb_twotime_qmap_cmap.setItemText(1, _translate("mainWindow", "jet"))
        self.cb_twotime_qmap_cmap.setItemText(2, _translate("mainWindow", "hot"))
        self.cb_twotime_qmap_cmap.setItemText(3, _translate("mainWindow", "plasma"))
        self.cb_twotime_qmap_cmap.setItemText(4, _translate("mainWindow", "viridis"))
        self.cb_twotime_qmap_cmap.setItemText(5, _translate("mainWindow", "magma"))
        self.twotime_autorotate.setText(_translate("mainWindow", "auto-rotate?"))
        self.cb_twotime_type.setItemText(0, _translate("mainWindow", "log"))
        self.cb_twotime_type.setItemText(1, _translate("mainWindow", "linear"))
        self.label_35.setText(_translate("mainWindow", "sax2d_cmap:"))
        self.label_37.setText(_translate("mainWindow", "qmap_cmap:"))
        self.pushButton_12.setText(_translate("mainWindow", "Plot"))
        self.label_27.setText(_translate("mainWindow", "q_index:"))
        self.label_28.setText(_translate("mainWindow", "twotime_cmap:"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_8), _translate("mainWindow", "Two Time"))
        self.hdf_key_filter.setPlaceholderText(_translate("mainWindow", "filter strings, seperate by space, press enter to apply"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_9), _translate("mainWindow", "Exp Setup"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_10), _translate("mainWindow", "Log"))
from .plothandler import ImageViewDev, MplCanvasBarH, MplCanvasBarV, PlotWidgetDev
from pyqtgraph import DataTreeWidget
from . import icons_rc
